@@ -1,9 +1,5 @@
-from flask.ext.babel import format_datetime, format_date
-from flask import render_template
 from datetime import datetime
 from urllib.parse import quote
-import os
-import json
 
 def timesince(dt, default="Just now."):
     """
@@ -25,8 +21,8 @@ def timesince(dt, default="Just now."):
     )
 
     for period, singular, plural in periods:
-        
-        if period:
+        period = round(period)
+        if period >= 1:
             return "%d %s ago" % (period, singular if period == 1 else plural)
 
     return default
@@ -35,6 +31,8 @@ def local_date(datestamp):
     """
     Returns a babel formatted local date
     """
+    from flask.ext.babel import format_date
+
     if datestamp:
         return format_date(datestamp)
 
@@ -49,29 +47,8 @@ def local_date_time(datestamp):
     """
     Returns a babel formatted local date and time
     """
+    from flask.ext.babel import format_datetime
+
     if datestamp:
         return format_datetime(datestamp)
 
-# Use a factory to set the app variable.
-def get_autoincluded_assets(app):
-    """
-    A Factory wrapper which returns a function which
-    generates head tag assets for the site.
-    """
-    def func(**kwargs):
-        """
-        Generates <head> tag assets for the site
-        and returns a string.
-        """
-        fn = os.path.realpath('./Application/static/vendor/autoinclude.json')
-        data = None
-        with open(fn, 'r') as f:
-            data = json.loads(f.read())
-
-        if data and 'scripts' in data and 'stylesheets' in data:
-            with app.app_context():
-                return render_template('_boilerplate/sources.html', 
-                    scripts=data['scripts'], 
-                    stylesheets=data['stylesheets'])
-
-    return func
